@@ -3,7 +3,7 @@
 package apis
 
 import (
-	v1 "github.com/open-cluster-management/cert-policy-controller/pkg/apis/policies/v1"
+	v1 "github.com/stolostron/cert-policy-controller/pkg/apis/policies/v1"
 )
 
 func init() {
